@@ -6,18 +6,19 @@
 */
 
 #include "kmimeassociations_p.h"
-#include <kservice.h>
-#include <kservicefactory_p.h>
-#include <KConfigGroup>
+#include "sycocadebug.h"
 #include <KConfig>
+#include <KConfigGroup>
 #include <QDebug>
 #include <QFile>
-#include <QStandardPaths>
 #include <QMimeDatabase>
-#include "sycocadebug.h"
+#include <QStandardPaths>
+#include <kservice.h>
+#include <kservicefactory_p.h>
 
 KMimeAssociations::KMimeAssociations(KOfferHash &offerHash, KServiceFactory *serviceFactory)
-    : m_offerHash(offerHash), m_serviceFactory(serviceFactory)
+    : m_offerHash(offerHash)
+    , m_serviceFactory(serviceFactory)
 {
 }
 
@@ -43,11 +44,7 @@ QStringList KMimeAssociations::mimeAppsFiles()
     QStringList mimeappsFileNames;
     // make the list of possible filenames from the spec ($desktop-mimeapps.list, then mimeapps.list)
     const QString desktops = QString::fromLocal8Bit(qgetenv("XDG_CURRENT_DESKTOP"));
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const auto list = desktops.split(QLatin1Char(':'), QString::SkipEmptyParts);
-#else
     const auto list = desktops.split(QLatin1Char(':'), Qt::SkipEmptyParts);
-#endif
     for (const QString &desktop : list) {
         mimeappsFileNames.append(desktop.toLower() + QLatin1String("-mimeapps.list"));
     }
@@ -56,7 +53,7 @@ QStringList KMimeAssociations::mimeAppsFiles()
     QStringList mimeappsFiles;
     // collect existing files
     for (const QString &dir : mimeappsDirs) {
-        for (const QString &file : qAsConst(mimeappsFileNames)) {
+        for (const QString &file : std::as_const(mimeappsFileNames)) {
             const QString filePath = dir + QLatin1Char('/') + file;
             if (QFile::exists(filePath) && !mimeappsFiles.contains(filePath)) {
                 mimeappsFiles.append(filePath);
@@ -69,8 +66,7 @@ QStringList KMimeAssociations::mimeAppsFiles()
 QStringList KMimeAssociations::mimeAppsDirs()
 {
     // list the dirs in the order of the spec (XDG_CONFIG_HOME, XDG_CONFIG_DIRS, XDG_DATA_HOME, XDG_DATA_DIRS)
-    return QStandardPaths::standardLocations(QStandardPaths::GenericConfigLocation)
-            + QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
+    return QStandardPaths::standardLocations(QStandardPaths::GenericConfigLocation) + QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
 }
 
 void KMimeAssociations::parseAllMimeAppsList()
@@ -81,7 +77,7 @@ void KMimeAssociations::parseAllMimeAppsList()
     mimeappsIter.toBack();
     while (mimeappsIter.hasPrevious()) { // global first, then local.
         const QString mimeappsFile = mimeappsIter.previous();
-        //qDebug() << "Parsing" << mimeappsFile;
+        // qDebug() << "Parsing" << mimeappsFile;
         parseMimeAppsList(mimeappsFile, basePreference);
         basePreference += 50;
     }
@@ -123,7 +119,7 @@ void KMimeAssociations::parseAddedAssociations(const KConfigGroup &group, const
                 if (!pService) {
                     qCDebug(SYCOCA) << file << "specifies unknown service" << service << "in" << group.name();
                 } else {
-                    //qDebug() << "adding mime" << resolvedMimeName << "to service" << pService->entryPath() << "pref=" << pref;
+                    // qDebug() << "adding mime" << resolvedMimeName << "to service" << pService->entryPath() << "pref=" << pref;
 #if KSERVICE_BUILD_DEPRECATED_SINCE(5, 69)
                     m_offerHash.addServiceOffer(resolvedMimeName, KServiceOffer(pService, pref, 0, pService->allowAsDefault()));
 #else
@@ -143,11 +139,11 @@ void KMimeAssociations::parseRemovedAssociations(const KConfigGroup &group, cons
     for (const QString &mime : keyList) {
         const QStringList services = group.readXdgListEntry(mime);
         for (const QString &service : services) {
-            KService::Ptr pService =  m_serviceFactory->findServiceByStorageId(service);
+            KService::Ptr pService = m_serviceFactory->findServiceByStorageId(service);
             if (!pService) {
-                //qDebug() << file << "specifies unknown service" << service << "in" << group.name();
+                // qDebug() << file << "specifies unknown service" << service << "in" << group.name();
             } else {
-                //qDebug() << "removing mime" << mime << "from service" << pService.data() << pService->entryPath();
+                // qDebug() << "removing mime" << mime << "from service" << pService.data() << pService->entryPath();
                 m_offerHash.removeServiceOffer(mime, pService);
             }
         }
@@ -157,7 +153,7 @@ void KMimeAssociations::parseRemovedAssociations(const KConfigGroup &group, cons
 void KOfferHash::addServiceOffer(const QString &serviceType, const KServiceOffer &offer)
 {
     KService::Ptr service = offer.service();
-    //qDebug() << "Adding" << service->entryPath() << "to" << serviceType << offer.preference();
+    // qDebug() << "Adding" << service->entryPath() << "to" << serviceType << offer.preference();
     ServiceTypeOffersData &data = m_serviceTypeData[serviceType]; // find or create
     QList<KServiceOffer> &offers = data.offers;
     QSet<KService::Ptr> &offerSet = data.offerSet;
@@ -165,7 +161,7 @@ void KOfferHash::addServiceOffer(const QString &serviceType, const KServiceOffer
         offers.append(offer);
         offerSet.insert(service);
     } else {
-        //qDebug() << service->entryPath() << "already in" << serviceType;
+        // qDebug() << service->entryPath() << "already in" << serviceType;
         // This happens when mimeapps.list mentions a service (to make it preferred)
         // Update initialPreference to qMax(existing offer, new offer)
         QMutableListIterator<KServiceOffer> sfit(data.offers);
@@ -192,9 +188,9 @@ void KOfferHash::removeServiceOffer(const QString &serviceType, const KService::
 
 bool KOfferHash::hasRemovedOffer(const QString &serviceType, const KService::Ptr &service) const
 {
-    QHash<QString, ServiceTypeOffersData>::const_iterator it = m_serviceTypeData.find(serviceType);
-    if (it != m_serviceTypeData.end()) {
-        return (*it).removedOffers.contains(service);
+    auto it = m_serviceTypeData.constFind(serviceType);
+    if (it != m_serviceTypeData.cend()) {
+        return it.value().removedOffers.contains(service);
     }
     return false;
 }
